==> django-fperms-iscore-0.2.8.tar.gz: django-fperms-iscore-0.2.8/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import re
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


def get_version(*file_paths):
    """Retrieves the version from fperms_iscore/__init__.py"""
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = open(filename).read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError('Unable to find version string.')


version = get_version("fperms_iscore", "__init__.py")


if sys.argv[-1] == 'publish':
    try:
        import wheel
        print("Wheel version: ", wheel.__version__)
    except ImportError:
        print('Wheel library missing. Please run "pip install wheel"')
        sys.exit()
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()

if sys.argv[-1] == 'tag':
    print("Tagging the version on git:")
    os.system("git tag -a %s -m 'version %s'" % (version, version))
    os.system("git push --tags")
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

setup(
    name='django-fperms-iscore',
    version=version,
    description="""Perms for iscore library """,
    long_description=readme + '\n\n' + history,
    author='Petr Olah',
    author_email='djangoguru@gmail.com',
    url='https://github.com/Formulka/django-fperms-iscore',
    download_url='https://github.com/formulka/django-fperms-iscore/archive/{}.tar.gz'.format(version),
    packages=[
        'fperms_iscore',
    ],
    include_package_data=True,
    install_requires=[
        "django-fperms==0.4.5",
        "django-is-core==2.18.0",
    ],
    license="MIT",
    zip_safe=False,
    keywords='django-fperms-iscore',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ]
)

==> django-fperms-iscore-0.2.12.tar.gz: django-fperms-iscore-0.2.12/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import re
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


def get_version(*file_paths):
    """Retrieves the version from fperms_iscore/__init__.py"""
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = open(filename).read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError('Unable to find version string.')


version = get_version("fperms_iscore", "__init__.py")


if sys.argv[-1] == 'publish':
    try:
        import wheel
        print("Wheel version: ", wheel.__version__)
    except ImportError:
        print('Wheel library missing. Please run "pip install wheel"')
        sys.exit()
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()

if sys.argv[-1] == 'tag':
    print("Tagging the version on git:")
    os.system("git tag -a %s -m 'version %s'" % (version, version))
    os.system("git push --tags")
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

setup(
    name='django-fperms-iscore',
    version=version,
    description="""Perms for iscore library """,
    long_description=readme + '\n\n' + history,
    author='Petr Olah',
    author_email='djangoguru@gmail.com',
    url='https://github.com/Formulka/django-fperms-iscore',
    download_url='https://github.com/formulka/django-fperms-iscore/archive/{}.tar.gz'.format(version),
    packages=[
        'fperms_iscore',
    ],
    include_package_data=True,
    install_requires=[
        "django-fperms>=0.4.6",
        "django-is-core>=2.21.3",
    ],
    license="MIT",
    zip_safe=False,
    keywords='django-fperms-iscore',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ]
)
